Index: third_party/WebKit/Source/platform/testing/PaintPrinters.h |
diff --git a/third_party/WebKit/Source/platform/testing/GeometryPrinters.h b/third_party/WebKit/Source/platform/testing/PaintPrinters.h |
similarity index 50% |
copy from third_party/WebKit/Source/platform/testing/GeometryPrinters.h |
copy to third_party/WebKit/Source/platform/testing/PaintPrinters.h |
index 589a13795db572400a8c57ada0cb0c89cd160a27..31f7ddcc41b7d2ed9198817fd91d7655c24a5b2a 100644 |
--- a/third_party/WebKit/Source/platform/testing/GeometryPrinters.h |
+++ b/third_party/WebKit/Source/platform/testing/PaintPrinters.h |
@@ -2,23 +2,17 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef GeometryPrinters_h |
-#define GeometryPrinters_h |
+#ifndef PaintPrinters_h |
+#define PaintPrinters_h |
-#include "platform/geometry/FloatRoundedRect.h" |
#include <iosfwd> |
namespace blink { |
-class FloatBox; |
-class FloatPoint; |
-class FloatPoint3D; |
-class FloatQuad; |
-class FloatRect; |
-class FloatSize; |
-class LayoutRect; |
+struct PaintChunk; |
+struct PaintProperties; |
-// GTest print support for geometry classes. |
+// GTest print support for platform paint classes. |
// |
// To avoid ODR violations, these should also be declared in the respective |
chrishtr
2015/10/05 17:23:41
ODR?
jbroman
2015/10/05 17:25:53
http://en.cppreference.com/w/cpp/language/definiti
jbroman
2015/10/05 18:05:07
Apparently you meant "what is the ODR violation"?
|
// headers defining these types. This is required because otherwise a template |
@@ -29,16 +23,9 @@ class LayoutRect; |
// use these printers. If, however, you get a link error about these symbols, |
// you need to make sure the blink_platform_test_support target is linked in |
// your unit test binary. |
-void PrintTo(const FloatBox&, std::ostream*); |
-void PrintTo(const FloatPoint&, std::ostream*); |
-void PrintTo(const FloatPoint3D&, std::ostream*); |
-void PrintTo(const FloatQuad&, std::ostream*); |
-void PrintTo(const FloatRect&, std::ostream*); |
-void PrintTo(const FloatRoundedRect&, std::ostream*); |
-void PrintTo(const FloatRoundedRect::Radii&, std::ostream*); |
-void PrintTo(const FloatSize&, std::ostream*); |
-void PrintTo(const LayoutRect&, std::ostream*); |
+void PrintTo(const PaintChunk&, std::ostream*); |
+void PrintTo(const PaintProperties&, std::ostream*); |
} // namespace blink |
-#endif // GeometryPrinters_h |
+#endif // PaintPrinters_h |